=== modified file 'drizzled/lex_input_stream.h'
--- drizzled/lex_input_stream.h	2011-04-16 13:00:30 +0000
+++ drizzled/lex_input_stream.h	2011-07-05 16:20:32 +0000
@@ -82,7 +82,7 @@
     Get the last character accepted.
     @return the last character accepted.
   */
-  char yyGetLast()
+  char yyGetLast() const
   {
     return m_ptr[-1];
   }
@@ -90,7 +90,7 @@
   /**
     Look at the next character to parse, but do not accept it.
   */
-  char yyPeek()
+  char yyPeek() const
   {
     return m_ptr[0];
   }
@@ -99,7 +99,7 @@
     Look ahead at some character to parse.
     @param n offset of the character to look up
   */
-  char yyPeekn(int n)
+  char yyPeekn(int n) const
   {
     return m_ptr[n];
   }
@@ -201,49 +201,49 @@
   }
 
   /** Get the token start position, in the raw buffer. */
-  const char *get_tok_start()
+  const char *get_tok_start() const
   {
     return m_tok_start;
   }
 
   /** Get the token start position, in the pre-processed buffer. */
-  const char *get_cpp_tok_start()
+  const char *get_cpp_tok_start() const
   {
     return m_cpp_tok_start;
   }
 
   /** Get the token end position, in the raw buffer. */
-  const char *get_tok_end()
+  const char *get_tok_end() const
   {
     return m_tok_end;
   }
 
   /** Get the token end position, in the pre-processed buffer. */
-  const char *get_cpp_tok_end()
+  const char *get_cpp_tok_end() const
   {
     return m_cpp_tok_end;
   }
 
   /** Get the previous token start position, in the raw buffer. */
-  const char *get_tok_start_prev()
+  const char *get_tok_start_prev() const
   {
     return m_tok_start_prev;
   }
 
   /** Get the current stream pointer, in the raw buffer. */
-  const char *get_ptr()
+  const char *get_ptr() const
   {
     return m_ptr;
   }
 
   /** Get the current stream pointer, in the pre-processed buffer. */
-  const char *get_cpp_ptr()
+  const char *get_cpp_ptr() const
   {
     return m_cpp_ptr;
   }
 
   /** Get the length of the current token, in the raw buffer. */
-  uint32_t yyLength()
+  uint32_t yyLength() const
   {
     /*
       The assumption is that the lexical analyser is always 1 character ahead,
@@ -254,13 +254,13 @@
   }
 
   /** Get the utf8-body string. */
-  const char *get_body_utf8_str()
+  const char *get_body_utf8_str() const
   {
     return m_body_utf8;
   }
 
   /** Get the utf8-body length. */
-  uint32_t get_body_utf8_length()
+  uint32_t get_body_utf8_length() const
   {
     return m_body_utf8_ptr - m_body_utf8;
   }

=== modified file 'drizzled/optimizer/cost_vector.h'
--- drizzled/optimizer/cost_vector.h	2011-03-14 05:40:28 +0000
+++ drizzled/optimizer/cost_vector.h	2011-07-05 16:20:32 +0000
@@ -19,13 +19,11 @@
 
 #pragma once
 
-namespace drizzled
-{
-namespace optimizer
-{
-class CostVector
-{
+namespace drizzled {
+namespace optimizer {
 
+class CostVector 
+{
 public:
   CostVector() :
     io_count(0.0),
@@ -35,7 +33,7 @@
     import_cost(0.0)
   {}
 
-  double total_cost()
+  double total_cost() const
   {
     return IO_COEFF*io_count*avg_io_cost + CPU_COEFF * cpu_cost +
       MEM_COEFF*mem_cost + IMPORT_COEFF*import_cost;

=== modified file 'drizzled/parser.cc'
--- drizzled/parser.cc	2011-07-05 14:36:13 +0000
+++ drizzled/parser.cc	2011-07-05 16:20:32 +0000
@@ -19,12 +19,13 @@
  */
 
 #include <config.h>
-#include <drizzled/session.h>
 #include <drizzled/parser.h>
 #include <drizzled/alter_info.h>
 #include <drizzled/create_field.h>
+#include <drizzled/item/subselect.h>
+#include <drizzled/lex_input_stream.h>
 #include <drizzled/message/alter_table.pb.h>
-#include <drizzled/item/subselect.h>
+#include <drizzled/session.h>
 #include <drizzled/sql_lex.h>
 
 namespace drizzled {

=== modified file 'drizzled/sql_lex.cc'
--- drizzled/sql_lex.cc	2011-07-05 15:59:49 +0000
+++ drizzled/sql_lex.cc	2011-07-05 16:20:32 +0000
@@ -34,6 +34,7 @@
 #include <drizzled/statement.h>
 #include <drizzled/sql_lex.h>
 #include <drizzled/plugin.h>
+#include <drizzled/lex_input_stream.h>
 
 #include <cstdio>
 #include <ctype.h>

=== modified file 'drizzled/sql_lex.h'
--- drizzled/sql_lex.h	2011-07-05 15:59:49 +0000
+++ drizzled/sql_lex.h	2011-07-05 16:20:32 +0000
@@ -769,10 +769,7 @@
 
 } /* namespace drizzled */
 
-#include <drizzled/lex_input_stream.h>
-
-namespace drizzled
-{
+namespace drizzled {
 
 /* The state of the lex parsing. This is saved in the Session struct */
 class LEX : public Query_tables_list

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2011-07-05 15:59:49 +0000
+++ drizzled/sql_parse.cc	2011-07-05 16:20:32 +0000
@@ -60,6 +60,7 @@
 #include <drizzled/session/times.h>
 #include <drizzled/session/transactions.h>
 #include <drizzled/create_field.h>
+#include <drizzled/lex_input_stream.h>
 
 #include <limits.h>
 

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2011-07-05 14:57:10 +0000
+++ drizzled/sql_yacc.yy	2011-07-05 16:20:32 +0000
@@ -48,6 +48,7 @@
 #include <drizzled/table_ident.h>
 #include <drizzled/var.h>
 #include <drizzled/system_variables.h>
+#include <drizzled/lex_input_stream.h>
 
 int yylex(union ParserType *yylval, drizzled::Session *session);
 

=== modified file 'drizzled/table_list.h'
--- drizzled/table_list.h	2011-07-05 15:22:15 +0000
+++ drizzled/table_list.h	2011-07-05 16:20:32 +0000
@@ -115,7 +115,7 @@
   const char *db;
 
 public:
-  const char *getSchemaName()
+  const char *getSchemaName() const
   {
     return db;
   }
@@ -137,7 +137,7 @@
   const char *table_name;
 
 public:
-  const char *getTableName()
+  const char *getTableName() const
   {
     return table_name;
   }

